# area4
Dividers in Python, the easy way!  Many different types.  [(As seen on PyPI!)](https://pypi.org/project/area4)  

<span style="text-align: center;">[![Vulnerabilities Badge](https://snyk.io/test/github/RDIL/area4/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/RDIL/area4?targetFile=requirements.txt) ![Travis Build](https://travis-ci.com/RDIL/area4.svg?branch=master) ![](https://img.shields.io/badge/license-MIT-green.svg) [![PyPi Project Version](https://badge.fury.io/py/area4.svg)](https://pypi.org/project/area4) [![CodeFactor](https://www.codefactor.io/repository/github/rdil/area4/badge)](https://www.codefactor.io/repository/github/rdil/area4) [![Documentation Status](https://readthedocs.org/projects/area4/badge/?version=latest)](https://area4.readthedocs.io/en/latest/?badge=latest) [![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active) [![Build Status](https://api.cirrus-ci.com/github/RDIL/area4.svg)](https://cirrus-ci.com/github/RDIL/area4)</span>  

## **[Documentation can be found here](https://area4.readthedocs.io/en/latest/)** <-------  
